fn credit_registration_config(course_code: &str) -> CreditRegistrationSeedExpand description
Turns the module on with an enrolment link unique to its course code, without which the config check flags the module, and opts its linked students’ completions in.