async fn enroll(
conn: &mut PgConnection,
user_id: Uuid,
course_id: Uuid,
course_instance_id: Uuid,
) -> Result<()>Expand description
Enrols the way a student who has been through the course’s opening dialogs is: without
user_course_settings and the AI notice acknowledgement, the course pages open on a dialog.